@@ -3,6 +3,7 @@ import os
 
 import igl
 import numpy as np
+import scipy as sp
 import scipy.sparse.csc as csc
 import math
 
@@ -946,6 +947,24 @@ class TestBasic(unittest.TestCase):
         self.assertEqual(q.dtype, self.v1.dtype)
         self.assertEqual(q.shape, (self.v1.shape[0], self.v1.shape[0]))
 
+    def test_signed_distance(self):
+        min_v = np.min(self.v1, axis=0)
+        max_v = np.max(self.v1, axis=0)
+        n = 16
+        g = np.mgrid[min_v[0]:max_v[0]:complex(n), min_v[1]:max_v[1]:complex(n), min_v[2]:max_v[2]:complex(n)]
+        p = np.vstack(map(np.ravel, g)).T
+        s, i, c = igl.signed_distance(p, self.v1, self.f1)
+
+        self.assertEqual(s.shape[0], p.shape[0])
+        self.assertEqual(i.shape[0], p.shape[0])
+        self.assertEqual(c.shape, p.shape)
+
+        s, i, c, n = igl.signed_distance(p, self.v1, self.f1, return_normals=True)
+        self.assertEqual(s.shape[0], p.shape[0])
+        self.assertEqual(i.shape[0], p.shape[0])
+        self.assertEqual(c.shape, p.shape)
+        self.assertEqual(n.shape, p.shape)
+
     # def test_offset_surface(self):
     #     sv, sf, gv, side, so = igl.offset_surface(self.v1, self.f1, 1, 10, igl.SIGNED_DISTANCE_TYPE_DEFAULT)
     #     self.assertEqual(sv.dtype, self.v1.type)
@@ -970,6 +989,30 @@ class TestBasic(unittest.TestCase):
     #def test_flip_avoid_line_search(self):
     #    pass
 
+    def test_min_quad_with_fixed(self):
+        v, f = igl.read_triangle_mesh(os.path.join(self.test_path, "cheburashka.off"))
+
+        ## Two fixed points: Left hand, left foot should have values 1 and -1
+        b = np.array([4331, 5957])
+        bc = np.array([1., -1.])
+        B = np.zeros((v.shape[0], 1))
+
+        ## Construct Laplacian and mass matrix
+        L = igl.cotmatrix(v, f)
+        M = igl.massmatrix(v, f, igl.MASSMATRIX_TYPE_VORONOI)
+        Minv = sp.sparse.diags(1 / M.diagonal())
+
+        ## Bi-Laplacian
+        Q = L @ (Minv @ L)
+
+        ## Solve with only equality constraints
+        Aeq = sp.sparse.csc_matrix((0, 0))
+        Beq = np.array([])
+        ok, z1 = igl.min_quad_with_fixed(Q, B, b, bc, Aeq, Beq, True)
+        self.assertTrue(z1.flags.c_contiguous)
+        self.assertTrue(z1.dtype == B.dtype)
+        self.assertTrue(ok)
+
 
 if __name__ == '__main__':
     unittest.main()
